<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="103"/>
        <source>Actions:</source>
        <translation>Ações:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="122"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="226"/>
        <source>Clear All</source>
        <translation>Limpar tudo</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="234"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="241"/>
        <location filename="../notifyd.cpp" line="298"/>
        <location filename="../notifyd.cpp" line="318"/>
        <source>%1 Unattended Notification(s)</source>
        <translation>%1 novas notificações</translation>
    </message>
</context>
</TS>
